==> promotion-service-v0.1.2.zip: promotion-service-v0.1.2/src/main/java/com/wangxiaolu/promotion/utils/QinCeUtils.java <==
package com.wangxiaolu.promotion.utils;

import cn.hutool.core.date.DatePattern;
import cn.hutool.core.date.DateTime;
import cn.hutool.core.date.DateUtil;
import cn.hutool.core.date.format.DatePrinter;
import com.alibaba.fastjson.JSONObject;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.codec.digest.DigestUtils;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Component;
import org.springframework.util.CollectionUtils;

import java.util.*;

/**
 * @author : liqiulin
 * @date : 2024-03-29 18
 * @describe : 勤策 api请求配置
 */
@Component
@Slf4j
public class QinCeUtils {

    /**
     * =================== 勤策API - config ===================
     */
    @Value("${qince.open_api}")
    private String OPEN_API;
    @Value("${qince.open_id}")
    private String OPEN_ID;
    @Value("${qince.app_key}")
    private String APP_KEY;


    /**
     * =================== 勤策API - path ===================
     */
    // 部门、组织架构
    public static final String QUERY_ORGANIZATION = "/api/organization/v1/queryOrganization/";
    // 员工列表
    public static final String QUERY_EMPLOYEE = "/api/employee/v3/queryEmployee/";
    // 终端（商店）列表
    public static final String QUERY_SHORE = "/api/store/v1/queryStore/";
    // 客户位置偏差查询
    public static final String CAL_DISTANCE = "/api/cmLocation/v1/calDistance/";
    // 商品类型查询
    public static final String QUERY_PRODUCT_PD_TYPE = "/api/product/v1/queryPdType/";
    // 商品列表
    public static final String QUERY_PRODUCT = "/api/product/v1/queryProduct/";

    public String builderUrl(String sidepath, Map<String, Object> params) {
        String msgId = UUID.randomUUID().toString();
        Long currentTimeMillis = System.currentTimeMillis();

        String digest = getDigest(params, currentTimeMillis);
        StringBuilder builder = new StringBuilder().append(OPEN_API).append(sidepath).append(OPEN_ID).append("/").append(currentTimeMillis).append("/").append(digest).append("/").append(msgId);
        return builder.toString();
    }

    public String builderUrlList(String sidepath, List<Map> paramList) {
        String msgId = UUID.randomUUID().toString();
        Long currentTimeMillis = System.currentTimeMillis();

        String digest = getDigest(paramList, currentTimeMillis);
        StringBuilder builder = new StringBuilder().append(OPEN_API).append(sidepath).append(OPEN_ID).append("/").append(currentTimeMillis).append("/").append(digest).append("/").append(msgId);
        return builder.toString();
    }

    /**
     * 查询[部门]参数
     */
    public Map<String, Object> productQueryPdTypeParam() {
        Map<String, Object> params = new HashMap<>();
        params.put("type_name", "");
        params.put("type_id", "");
        return params;
    }

    /**
     * 查询[部门]参数
     */
    public Map<String, Object> queryOrgParam() {
        Map<String, Object> params = new HashMap<>();
        params.put("id", "");
        params.put("org_id", "");
        params.put("org_code", "");
        params.put("org_name", "");
        params.put("org_status", "");
        params.put("create_date", "");
        params.put("modify_date", "");
        return params;
    }

    /**
     * 查询[人员]参数
     */
    public Map<String, Object> queryEmployeeParam(boolean queryId) {
        Map<String, Object> params = new HashMap<>();
        // 根据来源勤策的员工唯一标识精确查询
        if (queryId) {
            params.put("id", "");
        }

        // 根据来源第三方系统的员工唯一标识精确查询，id、emp_id如果同时存在优先取id
        params.put("emp_id", "");
        // 根据员工登录帐号精确查询
        params.put("emp_code", "");
        // 根据姓名模糊查询
        params.put("emp_name", "");
        // 根据人员编码精确查询
        params.put("employee_code", "");
        // 根据员工状态查询
        params.put("emp_status", "");
        // 根据创建日期查询用户。格式：yyyy-MM-dd
        params.put("create_date", "");
        // 根据修改日期查询用户。格式：yyyy-MM-dd
        params.put("modify_date", "");
        // 根据手机号查询
        params.put("emp_mobile", "");
        return params;
    }

    /**
     * 查询[客户管理-终端]参数
     */
    public Map<String, Object> queryShopParam(Integer pageNum) {
        HashMap<String, Object> params = new HashMap<>();
        // 分页页码，默认1
        params.put("page_number", pageNum);
        // 记录状态。0：已删除(客户回收站中的终端数据)，1：正常
//        params.put("status", "1");
        // after_modify_date：更新时间之后，查询更新时间之后的门店数据。格式：yyyy-MM-dd HH:mm:SS
        DateTime dateTime = DateUtil.offsetDay(new Date(), -7);
        params.put("after_modify_date", DateUtil.format(dateTime, DatePattern.NORM_DATETIME_PATTERN));
        return params;
    }

    /**
     * 客户位置偏差查询 参数
     * longitude:经度
     * latitude:纬度
     */
    public List<Map> queryCalDistanceParam(String storeQcId, String longitude, String latitude) {
        Map<String, Object> params = new HashMap<>();
        params.put("qince_customer_id", storeQcId);
        params.put("longitude", longitude);
        params.put("latitude", latitude);
        return Arrays.asList(params);
    }

    private String getDigest(Map<String, Object> params, Long currentTimeMillis) {
        String json = "";
        if (!CollectionUtils.isEmpty(params)) {
            json = JSONObject.toJSONString(params);
        }
        String digest = DigestUtils.md5Hex(json + "|" + APP_KEY + "|" + currentTimeMillis);
        return digest;
    }

    private String getDigest(List<Map> paramList, Long currentTimeMillis) {
        String json = "";
        if (!CollectionUtils.isEmpty(paramList)) {
            json = JSONObject.toJSONString(paramList);
        }
        String digest = DigestUtils.md5Hex(json + "|" + APP_KEY + "|" + currentTimeMillis);
        return digest;
    }

    public Map<String, Object> queryProductParam() {
        Map<String, Object> params = new HashMap<>();
        params.put("prd_id", "");
        return params;
    }
}

==> promotion-service-0.1.9.zip: promotion-service-0.1.9/src/main/java/com/wangxiaolu/promotion/utils/QinCeUtils.java <==
package com.wangxiaolu.promotion.utils;

import cn.hutool.core.date.DatePattern;
import cn.hutool.core.date.DateTime;
import cn.hutool.core.date.DateUtil;
import cn.hutool.core.date.format.DatePrinter;
import com.alibaba.fastjson.JSONObject;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.codec.digest.DigestUtils;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Component;
import org.springframework.util.CollectionUtils;

import java.util.*;

/**
 * @author : liqiulin
 * @date : 2024-03-29 18
 * @describe : 勤策 api请求配置
 */
@Component
@Slf4j
public class QinCeUtils {

    /**
     * =================== 勤策API - config ===================
     */
    @Value("${qince.open_api}")
    private String OPEN_API;
    @Value("${qince.open_id}")
    private String OPEN_ID;
    @Value("${qince.app_key}")
    private String APP_KEY;


    /**
     * =================== 勤策API - path ===================
     */
    // 部门、组织架构
    public static final String QUERY_ORGANIZATION = "/api/organization/v1/queryOrganization/";
    // 员工列表
    public static final String QUERY_EMPLOYEE = "/api/employee/v3/queryEmployee/";
    // 终端（商店）列表
    public static final String QUERY_SHORE = "/api/store/v1/queryStore/";
    // 客户位置偏差查询
    public static final String CAL_DISTANCE = "/api/cmLocation/v1/calDistance/";
    // 商品类型查询
    public static final String QUERY_PRODUCT_PD_TYPE = "/api/product/v1/queryPdType/";
    // 商品列表
    public static final String QUERY_PRODUCT = "/api/product/v1/queryProduct/";
    // 经销商
    public static final String QUERY_DEALER = "/api/dealer/v1/queryDealer/";

    public String builderUrl(String sidepath, Map<String, Object> params) {
        String msgId = UUID.randomUUID().toString();
        Long currentTimeMillis = System.currentTimeMillis();

        String digest = getDigest(params, currentTimeMillis);
        StringBuilder builder = new StringBuilder().append(OPEN_API).append(sidepath).append(OPEN_ID).append("/").append(currentTimeMillis).append("/").append(digest).append("/").append(msgId);
        return builder.toString();
    }

    public String builderUrlList(String sidepath, List<Map> paramList) {
        String msgId = UUID.randomUUID().toString();
        Long currentTimeMillis = System.currentTimeMillis();

        String digest = getDigest(paramList, currentTimeMillis);
        StringBuilder builder = new StringBuilder().append(OPEN_API).append(sidepath).append(OPEN_ID).append("/").append(currentTimeMillis).append("/").append(digest).append("/").append(msgId);
        return builder.toString();
    }

    /**
     * 查询[部门]参数
     */
    public Map<String, Object> productQueryPdTypeParam() {
        Map<String, Object> params = new HashMap<>();
        params.put("type_name", "");
        params.put("type_id", "");
        return params;
    }

    /**
     * 查询[部门]参数
     */
    public Map<String, Object> queryOrgParam() {
        Map<String, Object> params = new HashMap<>();
        DateTime dateTime = DateUtil.offsetDay(new Date(), -1);
        params.put("modify_date", DateUtil.format(dateTime, DatePattern.NORM_DATE_PATTERN));
        return params;
    }

    /**
     * 查询[人员]参数
     */
    public Map<String, Object> queryEmployeeParam(boolean queryId) {
        Map<String, Object> params = new HashMap<>();
        // 根据来源勤策的员工唯一标识精确查询
        if (queryId) {
            params.put("id", "");
        }
        DateTime dateTime = DateUtil.offsetDay(new Date(), -1);
        params.put("modify_date", DateUtil.format(dateTime, DatePattern.NORM_DATE_PATTERN));
        return params;
    }

    /**
     * 查询[客户管理-终端]参数
     */
    public Map<String, Object> queryShopParam(Integer pageNum) {
        HashMap<String, Object> params = new HashMap<>();
        // 分页页码，默认1
        params.put("page_number", pageNum);
        // 记录状态。0：已删除(客户回收站中的终端数据)，1：正常
//        params.put("status", "1");
        // after_modify_date：更新时间之后，查询更新时间之后的门店数据。格式：yyyy-MM-dd HH:mm:SS
        DateTime dateTime = DateUtil.offsetDay(new Date(), -7);
        params.put("after_modify_date", DateUtil.format(dateTime, DatePattern.NORM_DATETIME_PATTERN));
        return params;
    }

    /**
     * 客户位置偏差查询 参数
     * longitude:经度
     * latitude:纬度
     */
    public List<Map> queryCalDistanceParam(String storeQcId, String longitude, String latitude) {
        Map<String, Object> params = new HashMap<>();
        params.put("qince_customer_id", storeQcId);
        params.put("longitude", longitude);
        params.put("latitude", latitude);
        return Arrays.asList(params);
    }

    private String getDigest(Map<String, Object> params, Long currentTimeMillis) {
        String json = "";
        if (!CollectionUtils.isEmpty(params)) {
            json = JSONObject.toJSONString(params);
        }
        String digest = DigestUtils.md5Hex(json + "|" + APP_KEY + "|" + currentTimeMillis);
        return digest;
    }

    private String getDigest(List<Map> paramList, Long currentTimeMillis) {
        String json = "";
        if (!CollectionUtils.isEmpty(paramList)) {
            json = JSONObject.toJSONString(paramList);
        }
        String digest = DigestUtils.md5Hex(json + "|" + APP_KEY + "|" + currentTimeMillis);
        return digest;
    }

    public Map<String, Object> queryProductParam() {
        Map<String, Object> params = new HashMap<>();
        params.put("prd_id", "");
        return params;
    }

    public Map<String, Object> queryDealerParam(Integer pageNum) {
        Map<String, Object> params = new HashMap<>();
        params.put("page_number", pageNum);
        params.put("status", "1");

        // todo 全量数据同步后，再开启指定日期同步
//        DateTime dateTime = DateUtil.offsetDay(new Date(), -7);
//        params.put("after_create_date", DateUtil.format(dateTime, DatePattern.NORM_DATETIME_PATTERN));
        return params;
    }
}
